@@ -19,7 +19,6 @@ enum {
 	DHO,
 	DHODEC,
 	DREF,
-	DNAT,
 	DCTRL,
 	DFILTER,
 	DPCU,
@@ -28,6 +27,8 @@ enum {
 	DTS,
 	DAS,
 	DCBS,
+	DLCS,
+	DRESET,
 	Debug_LastEntry,
 };
 
